Crate kcr_elbv2_k8s_aws

Crate kcr_elbv2_k8s_aws 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the elbv2.k8s.aws group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

elbv2.k8s.aws/v1alpha1

  • TargetGroupBinding

elbv2.k8s.aws/v1beta1

  • IngressClassParams
  • TargetGroupBinding

Modules

v1alpha1
v1beta1